==> TencentNavKitDocument_6.13.0.zip: TencentNavKitDocument/interface_t_n_k_drive_navigation_data.js <==
var interface_t_n_k_drive_navigation_data =
[
    [ "currentRoadName", "interface_t_n_k_drive_navigation_data.html#aa3be655393b72ad098ccdb765ce841a4", null ],
    [ "currentSpeed", "interface_t_n_k_drive_navigation_data.html#a42b152218b03e621d1989629075196ed", null ],
    [ "electronicEyeInfo", "interface_t_n_k_drive_navigation_data.html#a696c2467406ac80a1a7a33ecc12aaa4c", null ],
    [ "entranceName", "interface_t_n_k_drive_navigation_data.html#aa4eb039b39432a5c24cf8682410e5f4c", null ],
    [ "exitName", "interface_t_n_k_drive_navigation_data.html#a344420322706073154baa6c12079e67b", null ],
    [ "highwayFacilityInfo", "interface_t_n_k_drive_navigation_data.html#ad7d37d380a12b84a0071cc07346da395", null ],
    [ "intersectionImage", "interface_t_n_k_drive_navigation_data.html#a23933b31b34d62917fba64904c278105", null ],
    [ "intersectionType", "interface_t_n_k_drive_navigation_data.html#a29dce40cd2d563fcd651def74ee75b48", null ],
    [ "isOverSpeed", "interface_t_n_k_drive_navigation_data.html#abe569724c51907da244108ccf9b8369a", null ],
    [ "isShowingTipsMap", "interface_t_n_k_drive_navigation_data.html#a9ed32d46678445b630d738ba11769791", null ],
    [ "limitSpeed", "interface_t_n_k_drive_navigation_data.html#aebc9f0979fd6c817fee0d623bfb68837", null ],
    [ "navRestrictionInfo", "interface_t_n_k_drive_navigation_data.html#a1c568ab2f271d1cb8dd94f4334dd2419", null ],
    [ "nextDistanceLeft", "interface_t_n_k_drive_navigation_data.html#ad2b63b9fcc513a83bffd9d4e67c1cc95", null ],
    [ "nextIntersectionImage", "interface_t_n_k_drive_navigation_data.html#a81cf79eb3eafdac22acef837fa202ed6", null ],
    [ "nextNextRoadName", "interface_t_n_k_drive_navigation_data.html#a2f296d9bf2aa2432be2f850732fc2a68", null ],
    [ "nextRoadName", "interface_t_n_k_drive_navigation_data.html#a1e8237f78202e0f08afe281aa01f72b8", null ],
    [ "passedDistance", "interface_t_n_k_drive_navigation_data.html#acf2906b6ca1477c9e2616148c208c80d", null ],
    [ "passedTime", "interface_t_n_k_drive_navigation_data.html#ae612c40fb996011a5e02aed62ff1e6d3", null ],
    [ "remainTrafficLightCount", "interface_t_n_k_drive_navigation_data.html#ac66ef793ca9e59f46e2483993bdfcc55", null ],
    [ "speedMonitorStatus", "interface_t_n_k_drive_navigation_data.html#a01a7adcd9a8cad2e09b778ecdf82410a", null ],
    [ "tipsRemainingDistance", "interface_t_n_k_drive_navigation_data.html#a8c96efcd658c33d9064b64c6dce3f345", null ],
    [ "tipsText", "interface_t_n_k_drive_navigation_data.html#a35036fcb2160bab0fa0f097721d7f9b5", null ],
    [ "totalDistanceLeft", "interface_t_n_k_drive_navigation_data.html#ae4f56809abe4569aa5bf4ba0217071a6", null ],
    [ "totalTimeLeft", "interface_t_n_k_drive_navigation_data.html#a72cfa962357a9b87a97011d88341a31f", null ],
    [ "waypoints", "interface_t_n_k_drive_navigation_data.html#a3175be29bb28f44f6272355d5a6a5078", null ]
];

==> TencentNavKitDocument_7.1.1.zip: TencentNavKitDocument/interface_t_n_k_drive_navigation_data.js <==
var interface_t_n_k_drive_navigation_data =
[
    [ "currentRoadName", "interface_t_n_k_drive_navigation_data.html#aa3be655393b72ad098ccdb765ce841a4", null ],
    [ "currentSpeed", "interface_t_n_k_drive_navigation_data.html#a42b152218b03e621d1989629075196ed", null ],
    [ "electronicEyeInfo", "interface_t_n_k_drive_navigation_data.html#a696c2467406ac80a1a7a33ecc12aaa4c", null ],
    [ "entranceName", "interface_t_n_k_drive_navigation_data.html#aa4eb039b39432a5c24cf8682410e5f4c", null ],
    [ "exitName", "interface_t_n_k_drive_navigation_data.html#a344420322706073154baa6c12079e67b", null ],
    [ "highwayFacilityInfo", "interface_t_n_k_drive_navigation_data.html#ad7d37d380a12b84a0071cc07346da395", null ],
    [ "intersectionImage", "interface_t_n_k_drive_navigation_data.html#a23933b31b34d62917fba64904c278105", null ],
    [ "intersectionType", "interface_t_n_k_drive_navigation_data.html#a29dce40cd2d563fcd651def74ee75b48", null ],
    [ "isOverSpeed", "interface_t_n_k_drive_navigation_data.html#abe569724c51907da244108ccf9b8369a", null ],
    [ "isShowingTipsMap", "interface_t_n_k_drive_navigation_data.html#a9ed32d46678445b630d738ba11769791", null ],
    [ "limitSpeed", "interface_t_n_k_drive_navigation_data.html#aebc9f0979fd6c817fee0d623bfb68837", null ],
    [ "navRestrictionInfo", "interface_t_n_k_drive_navigation_data.html#a1c568ab2f271d1cb8dd94f4334dd2419", null ],
    [ "nextDistanceLeft", "interface_t_n_k_drive_navigation_data.html#ad2b63b9fcc513a83bffd9d4e67c1cc95", null ],
    [ "nextIntersectionImage", "interface_t_n_k_drive_navigation_data.html#a81cf79eb3eafdac22acef837fa202ed6", null ],
    [ "nextNextRoadName", "interface_t_n_k_drive_navigation_data.html#a2f296d9bf2aa2432be2f850732fc2a68", null ],
    [ "nextRoadName", "interface_t_n_k_drive_navigation_data.html#a1e8237f78202e0f08afe281aa01f72b8", null ],
    [ "overSpeedType", "interface_t_n_k_drive_navigation_data.html#ad886e7f70ba6b629e180815672bfccba", null ],
    [ "passedDistance", "interface_t_n_k_drive_navigation_data.html#acf2906b6ca1477c9e2616148c208c80d", null ],
    [ "passedTime", "interface_t_n_k_drive_navigation_data.html#ae612c40fb996011a5e02aed62ff1e6d3", null ],
    [ "remainTrafficLightCount", "interface_t_n_k_drive_navigation_data.html#ac66ef793ca9e59f46e2483993bdfcc55", null ],
    [ "speedMonitorStatus", "interface_t_n_k_drive_navigation_data.html#a01a7adcd9a8cad2e09b778ecdf82410a", null ],
    [ "tipsRemainingDistance", "interface_t_n_k_drive_navigation_data.html#a8c96efcd658c33d9064b64c6dce3f345", null ],
    [ "tipsText", "interface_t_n_k_drive_navigation_data.html#a35036fcb2160bab0fa0f097721d7f9b5", null ],
    [ "totalDistanceLeft", "interface_t_n_k_drive_navigation_data.html#ae4f56809abe4569aa5bf4ba0217071a6", null ],
    [ "totalTimeLeft", "interface_t_n_k_drive_navigation_data.html#a72cfa962357a9b87a97011d88341a31f", null ],
    [ "waypoints", "interface_t_n_k_drive_navigation_data.html#a3175be29bb28f44f6272355d5a6a5078", null ]
];
